Learn R Programming

cartographr (version 0.2.4)

osm: OSM SoHo New York simple features

Description

This dataset contains the Simple Features (sf) representation for Soho, New York. It includes various geographical and spatial attributes relevant to the area.

Usage

osm

Arguments

Format

An named list of objects of class sf with rows and columns corresponding to the features and their attributes.

Examples

Run this code
data("osm")

Run the code above in your browser using DataLab