Skip to contents

This function prints the configuration details stored in the current environment. It iterates through the variables in the environment and displays their names and values.

Usage

print_config()

Value

This function does not return any value; it only prints the configuration details.

Examples

print_config()
#> ℹ attribution: TRUE
#> ℹ orientation: portrait
#> ℹ output_size: 210 297
#> ℹ scale_factor: 0.2497607