Learn R Programming

cartographr (version 0.2.4)

set_attribution: Set or get attribution setting

Description

This function sets a new value for the attribution setting in the cartographr environment or retrieves the current setting if no argument is provided.

Usage

set_attribution(attribution = NULL)

Value

If attribution is NULL, returns the current acknowledgments setting. If attribution is a logical value, the function will set the acknowledgments setting to that value and return invisibly.

Arguments

attribution

A logical value to set the acknowledgments setting. If NULL, the current setting is returned. The default is NULL.

Examples

Run this code
# To get the current acknowledgments setting
set_attribution()

# To set the acknowledgments setting to TRUE
set_attribution(TRUE)

Run the code above in your browser using DataLab