| theme_poster | R Documentation |
This function generates a 'ggplot2' theme that resembles a poster style. It is designed to be used with 'ggplot2' plots to provide a clean and bold aesthetic suitable for poster visuals.
theme_poster(font = "Poppins")
theme_poster_poppins()
theme_poster_anton()
theme_poster_cinzel()
theme_poster_barlow()
font |
The font family to be used for text elements in the plot. The default font is set to "Poppins". |
theme_poster_poppins(), theme_poster_anton() are aliases to theme_poster("Poppins"), etc.
A 'ggplot2' theme object that can be added to 'ggplot2' plotting calls.
data("osm")
my_map <- osm |> plot_map() +
theme_poster()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.