| print_config | R Documentation |
This function prints the configuration details stored in the current environment. It iterates through the variables in the environment and displays their names and values.
print_config()
This function does not return any value; it only prints the configuration details.
print_config()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.